@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -33,24 +35,28 @@
 #' Split a String Into Text Lines
 #'
 #' @description
-#' These functions split each character string into text lines.
+#' These functions split each character string in a given vector
+#' into text lines.
 #'
 #' @details
 #' Vectorized over \code{str} and \code{omit_empty}.
 #'
-#' \code{omit_empty} is applied during splitting. If it is set to \code{TRUE},
+#' \code{omit_empty} is applied when splitting. If set to \code{TRUE},
 #' then empty strings will never appear in the resulting vector.
 #'
-#' Newlines are represented on different platforms e.g. by carriage return
-#' (CR, 0x0D), line feed (LF, 0x0A), CRLF, or next line (NEL, 0x85).
+#' Newlines are represented with the Carriage Return
+#' (CR, 0x0D), Line Feed (LF, 0x0A), CRLF, or Next Line (NEL, 0x85) characters,
+#' depending on the platform.
 #' Moreover, the Unicode Standard defines two unambiguous separator characters,
-#' Paragraph Separator (PS, 0x2029) and Line Separator (LS, 0x2028).
-#' Sometimes also vertical tab (VT, 0x0B) and form feed (FF, 0x0C)
-#' are used. These functions follow UTR#18 rules, where a newline sequence
+#' the Paragraph Separator (PS, 0x2029) and the Line Separator (LS, 0x2028).
+#' Sometimes also the Vertical Tab (VT, 0x0B) and the Form Feed (FF, 0x0C)
+#' are used for this purpose.
+#'
+#' These \pkg{stringi} functions follow UTR#18 rules,
+#' where a newline sequence
 #' corresponds to the following regular expression:
 #' \code{(?:\\u\{D A\}|(?!\\u\{D A\})[\\u\{A\}-\\u\{D\}\\u\{85\}\\u\{2028\}\\u\{2029\}]}.
-#' Each match is used to split a text line. For efficiency reasons, the search
-#' here is not performed by the regex engine, however.
+#' Each match serves as a text line separator.
 #'
 #'
 #' @param str character vector (\code{stri_split_lines})
@@ -65,55 +71,55 @@
 #'
 #' \code{stri_split_lines1(str)} is equivalent to
 #' \code{stri_split_lines(str[1])[[1]]} (with default parameters),
-#' thus it returns a character vector. Moreover, if the input string ends at
-#' a newline sequence, the last empty string is omitted from the result.
-#' Therefore, this function may be handy if you wish to split a loaded text
-#' file into text lines.
+#' therefore it returns a character vector. Moreover, if the input string
+#' ends with a newline sequence, the last empty string is omitted from the
+#  result. This function may come in handy if you wish to split a text
+#' file's contents into text lines.
 #'
 #' @references
 #' \emph{Unicode Newline Guidelines} -- Unicode Technical Report #13,
-#' \url{http://www.unicode.org/standard/reports/tr13/tr13-5.html}
+#' \url{https://www.unicode.org/standard/reports/tr13/tr13-5.html}
 #'
 #' \emph{Unicode Regular Expressions} -- Unicode Technical Standard #18,
-#' \url{http://www.unicode.org/reports/tr18/}
+#' \url{https://www.unicode.org/reports/tr18/}
 #'
 #' @family search_split
 #' @family text_boundaries
 #' @export
 #' @rdname stri_split_lines
 #' @aliases stri_split_lines stri_split_lines1
-stri_split_lines <- function(str, omit_empty=FALSE) {
-   .Call(C_stri_split_lines, str, omit_empty)
+stri_split_lines <- function(str, omit_empty = FALSE) {
+    .Call(C_stri_split_lines, str, omit_empty)
 }
 
 
 #' @rdname stri_split_lines
 #' @export
 stri_split_lines1 <- function(str) {
-   .Call(C_stri_split_lines1, str)
+    .Call(C_stri_split_lines1, str)
 }
 
 
 #' @title
-#' Split a String at Specific Text Boundaries
+#' Split a String at Text Boundaries
 #'
 #' @description
-#' This function locates specific text boundaries
+#' This function locates text boundaries
 #' (like character, word, line, or sentence boundaries)
 #' and splits strings at the indicated positions.
 #'
 #' @details
 #' Vectorized over \code{str} and \code{n}.
 #'
-#' If \code{n} is negative (default), then all pieces are extracted.
-#' Otherwise, if \code{tokens_only} is \code{FALSE} (this is the default,
-#' for compatibility with the \pkg{stringr} package), then \code{n-1}
-#' tokes are extracted (if possible) and the \code{n}-th string
+#' If \code{n} is negative (the default), then all text pieces are extracted.
+#'
+#' Otherwise, if \code{tokens_only} is \code{FALSE} (which is the default),
+#' then \code{n-1} tokens are extracted (if possible) and the \code{n}-th string
 #' gives the (non-split) remainder (see Examples).
 #' On the other hand, if \code{tokens_only} is \code{TRUE},
 #' then only full tokens (up to \code{n} pieces) are extracted.
 #'
-#' For more information on the text boundary analysis
+#' For more information on text boundary analysis
 #' performed by \pkg{ICU}'s \code{BreakIterator}, see
 #' \link{stringi-search-boundaries}.
 #'
@@ -124,9 +130,9 @@ stri_split_lines1 <- function(str) {
 #' @param simplify single logical value; if \code{TRUE} or \code{NA},
 #' then a character matrix is returned; otherwise (the default), a list of
 #' character vectors is given, see Value
-#' @param opts_brkiter a named list with \pkg{ICU} BreakIterator's settings
-#' as generated with \code{\link{stri_opts_brkiter}}; \code{NULL} for the
-#' default break iterator, i.e. \code{line_break}
+#' @param opts_brkiter a named list with \pkg{ICU} BreakIterator's settings,
+#' see \code{\link{stri_opts_brkiter}}; \code{NULL} for the
+#' default break iterator, i.e., \code{line_break}
 #' @param ... additional settings for \code{opts_brkiter}
 #'
 #' @return If \code{simplify=FALSE} (the default),
@@ -140,28 +146,30 @@ stri_split_lines1 <- function(str) {
 #' for \code{simplify} equal to \code{TRUE} and \code{NA}, respectively.
 #'
 #' @examples
-#' test <- "The\u00a0above-mentioned    features are very useful. " %s+%
-#'    "Warm thanks to their developers. 123 456 789"
-#' stri_split_boundaries(test, type="line")
-#' stri_split_boundaries(test, type="word")
-#' stri_split_boundaries(test, type="word", skip_word_none=TRUE)
-#' stri_split_boundaries(test, type="word", skip_word_none=TRUE, skip_word_letter=TRUE)
-#' stri_split_boundaries(test, type="word", skip_word_none=TRUE, skip_word_number=TRUE)
-#' stri_split_boundaries(test, type="sentence")
-#' stri_split_boundaries(test, type="sentence", skip_sentence_sep=TRUE)
-#' stri_split_boundaries(test, type="character")
+#' test <- 'The\u00a0above-mentioned    features are very useful. ' %s+%
+#'    'Spam, spam, eggs, bacon, and spam. 123 456 789'
+#' stri_split_boundaries(test, type='line')
+#' stri_split_boundaries(test, type='word')
+#' stri_split_boundaries(test, type='word', skip_word_none=TRUE)
+#' stri_split_boundaries(test, type='word', skip_word_none=TRUE, skip_word_letter=TRUE)
+#' stri_split_boundaries(test, type='word', skip_word_none=TRUE, skip_word_number=TRUE)
+#' stri_split_boundaries(test, type='sentence')
+#' stri_split_boundaries(test, type='sentence', skip_sentence_sep=TRUE)
+#' stri_split_boundaries(test, type='character')
 #'
-#' # filtered break iterator with the new ICU:
-#' stri_split_boundaries("Mr. Jones and Mrs. Brown are very happy.
-#' So am I, Prof. Smith.", type="sentence", locale="@ss=standard") # ICU >= 56 only
+#' # a filtered break iterator with the new ICU:
+#' stri_split_boundaries('Mr. Jones and Mrs. Brown are very happy.
+#' So am I, Prof. Smith.', type='sentence', locale='en_US@ss=standard') # ICU >= 56 only
 #'
 #' @export
 #' @family search_split
 #' @family locale_sensitive
 #' @family text_boundaries
-stri_split_boundaries <- function(str, n=-1L,
-      tokens_only=FALSE, simplify=FALSE, ..., opts_brkiter=NULL) {
-   if (!missing(...))
-       opts_brkiter <- do.call(stri_opts_brkiter, as.list(c(opts_brkiter, ...)))
-   .Call(C_stri_split_boundaries, str, n, tokens_only, simplify, opts_brkiter)
+stri_split_boundaries <- function(str, n = -1L,
+    tokens_only = FALSE, simplify = FALSE,
+    ..., opts_brkiter = NULL)
+{
+    if (!missing(...))
+        opts_brkiter <- do.call(stri_opts_brkiter, as.list(c(opts_brkiter, ...)))
+    .Call(C_stri_split_boundaries, str, n, tokens_only, simplify, opts_brkiter)
 }
