@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,8 @@
 #define __stri_container_utf16_h
 
 #include "stri_container_base.h"
+#include <vector>
+
 
 /**
  * A class to handle conversion between R character vectors
@@ -45,7 +47,7 @@
  *          lastMatcher cache, supports auto-vectorization
  *
  * @version 0.1-?? (Marek Gagolewski)
- *          improved ASCII performance (seperate ucnv)
+ *          improved ASCII performance (separate ucnv)
  *
  * @version 0.1-?? (Marek Gagolewski)
  *          now NAs are marked as NULLs in str
@@ -158,4 +160,8 @@ public:
     void UChar16_to_UChar32_index(R_len_t i, int* i1, int* i2, const int ni, int adj1, int adj2);
 };
 
+
+SEXP stri__subset_by_logical(const StriContainerUTF16& str_cont,
+                             const std::vector<int>& which, int result_counter);
+
 #endif
