@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -64,8 +64,8 @@ StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallow
     this->str = NULL;
 
 #ifndef NDEBUG
-    if (!isString(rstr))
-        throw StriException("DEBUG: !isString in StriContainerUTF8::StriContainerUTF8(SEXP rstr)");
+    if (!Rf_isString(rstr))
+        throw StriException("DEBUG: !Rf_isString in StriContainerUTF8::StriContainerUTF8(SEXP rstr)");
 #endif
     R_len_t nrstr = LENGTH(rstr);
     this->init_Base(nrstr, _nrecycle, _shallowrecycle, rstr); // calling LENGTH(rstr) fails on constructor call
@@ -73,7 +73,7 @@ StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallow
     if (this->n == 0)
         return; /* nothing more to do */
 
-
+    STRI_ASSERT(this->n > 0);
     this->str = new String8[this->n];
     STRI_ASSERT(this->str);
     if (!this->str) throw StriException(MSG__MEM_ALLOC_ERROR_WITH_SIZE,
@@ -88,6 +88,7 @@ StriContainerUTF8::StriContainerUTF8(SEXP rstr, R_len_t _nrecycle, bool _shallow
     // #270: latin-1 is windows-1252 on Windows
     StriUcnv ucnvLatin1("WINDOWS-1252");
 #else
+    // TODO: WINDOWS-1252 is a superset of ISO-8859-1, use the former??
     StriUcnv ucnvLatin1("ISO-8859-1");
 #endif
     StriUcnv ucnvNative(NULL);
