@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -60,6 +60,7 @@
 #include <unicode/brkiter.h>
 #include <unicode/rbbi.h>
 #include <unicode/timezone.h>
+#include <unicode/calendar.h>
 using namespace icu;
 
 // #define USE_RINTERNALS  removed 2021-08-12 - do not use anymore
@@ -71,7 +72,9 @@ using namespace icu;
 #include <Rdefines.h>
 #include <R_ext/Rdynload.h>
 
-#ifndef ALTREP
+#if R_VERSION >= R_Version(3, 5, 0)
+
+#else
 /* ALTREP is R>=3.5.0 */
 #define ALTREP(x) (0)
 #endif
