@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -92,7 +92,7 @@
    "incorrect opts_regex setting: '%s'; ignoring"
 
 #define MSG__INVALID_CODE_POINT \
-   "invalid Unicode code point \\U%08.8x"
+   "invalid Unicode code point \\U%08x"
 
 #define MSG__INVALID_CODE_POINT_FIXING \
    "invalid UTF-8 code point definition; fixing"
@@ -112,22 +112,22 @@
 #define MSG_REPLACEMENT_MULTIPLE \
    "number of items to replace is not a multiple of replacement length"
 
-#define MSG__UNCONVERTABLE_CODE_POINT \
-   "the Unicode code point \\U%08.8x cannot be converted to destination encoding"
+#define MSG__UNCONVERTIBLE_CODE_POINT \
+   "the Unicode code point \\U%08x cannot be converted to destination encoding"
 
-#define MSG__UNCONVERTABLE_BINARY_1 \
-   "input data \\x%02.2x in the current source encoding could not be converted to Unicode"
+#define MSG__UNCONVERTIBLE_BINARY_1 \
+   "input data \\x%02x in the current source encoding could not be converted to Unicode"
 
-#define MSG__UNCONVERTABLE_BINARY_2 \
-   "input data \\x%02.2x\\x%02.2x in the current source encoding could not be converted to Unicode"
+#define MSG__UNCONVERTIBLE_BINARY_2 \
+   "input data \\x%02x\\x%02x in the current source encoding could not be converted to Unicode"
 
-#define MSG__UNCONVERTABLE_BINARY_3 \
-   "input data \\x%02.2x\\x%02.2x\\x%02.2x in the current source encoding could not be converted to Unicode"
+#define MSG__UNCONVERTIBLE_BINARY_3 \
+   "input data \\x%02x\\x%02x\\x%02x in the current source encoding could not be converted to Unicode"
 
-#define MSG__UNCONVERTABLE_BINARY_4 \
-   "input data \\x%02.2x\\x%02.2x\\x%02.2x\\x%02.2x in the current source encoding could not be converted to Unicode"
+#define MSG__UNCONVERTIBLE_BINARY_4 \
+   "input data \\x%02x\\x%02x\\x%02x\\x%02x in the current source encoding could not be converted to Unicode"
 
-#define MSG__UNCONVERTABLE_BINARY_n \
+#define MSG__UNCONVERTIBLE_BINARY_n \
    "some input data in the current source encoding could not be converted to Unicode"
 
 #define MSG__WARN_LIST_COERCION \
