@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -85,11 +85,11 @@ SEXP stri_split_regex(SEXP str, SEXP pattern, SEXP n, SEXP omit_empty,
                       SEXP tokens_only, SEXP simplify, SEXP opts_regex)
 {
     bool tokens_only1 = stri__prepare_arg_logical_1_notNA(tokens_only, "tokens_only");
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
-    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
-    PROTECT(n = stri_prepare_arg_integer(n, "n"));
-    PROTECT(omit_empty = stri_prepare_arg_logical(omit_empty, "omit_empty"));
-    PROTECT(simplify = stri_prepare_arg_logical_1(simplify, "simplify"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri__prepare_arg_string(pattern, "pattern"));
+    PROTECT(n = stri__prepare_arg_integer(n, "n"));
+    PROTECT(omit_empty = stri__prepare_arg_logical(omit_empty, "omit_empty"));
+    PROTECT(simplify = stri__prepare_arg_logical_1(simplify, "simplify"));
     R_len_t vectorize_length = stri__recycling_rule(true, 4,
                                LENGTH(str), LENGTH(pattern), LENGTH(n), LENGTH(omit_empty));
 
@@ -128,7 +128,7 @@ SEXP stri_split_regex(SEXP str, SEXP pattern, SEXP n, SEXP omit_empty,
         const char* str_cur_s = str_cont.get(i).c_str();
 
         if (n_cur >= INT_MAX-1)
-            throw StriException(MSG__EXPECTED_SMALLER, "n");
+            throw StriException(MSG__INCORRECT_NAMED_ARG "; " MSG__EXPECTED_SMALLER, "n");
         else if (n_cur < 0)
             n_cur = INT_MAX;
         else if (n_cur == 0) {
