@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
+ * Copyright (c) 2013-2025, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -89,7 +89,7 @@ Calendar* stri__get_calendar(const char* locale_val)
         UErrorCode status2 = U_ZERO_ERROR;
         const char* valid_locale = cal->getLocaleID(ULOC_VALID_LOCALE, status2);
         if (valid_locale && !strcmp(valid_locale, "root"))
-        Rf_warning(ICUError::getICUerrorName(status));
+        Rf_warning("%s", ICUError::getICUerrorName(status));
     }
 
     return cal;
@@ -480,7 +480,6 @@ SEXP stri_datetime_create(
 //  */
 // SEXP stri_c_posixst(SEXP x) {
 //     if (!Rf_isVectorList(x)) Rf_error(MSG__INTERNAL_ERROR);
-//     if (NAMED(x) != 0)  Rf_error(MSG__INTERNAL_ERROR);
 //     R_len_t n = LENGTH(x);
 //     R_len_t m = 0;
 //     for (R_len_t i=0; i<n; ++i) {
